package user

import (
	"context"
	"cp-organization-management/errors"
	"cp-organization-management/impl/v1/rbac"
	"cp-organization-management/model"
	pb_v1 "cp-organization-management/pb/v1"
	"cp-organization-management/utils"
	"cp-organization-management/consts"
	"fmt"
	"github.com/jaryhe/gopkgs/database"
	"github.com/jaryhe/gopkgs/util"
	"github.com/jinzhu/gorm"
	"go.uber.org/zap"
	"github.com/jaryhe/gopkgs/logger"
	"google.golang.org/grpc/status"
	"encoding/json"
	"cp-organization-management/pb"
	"time"
)

func ManagementLogin(ctx context.Context, req *pb_v1.ManagementLoginRequest)(reply *pb_v1.ManagementLoginReply, err error) {
	reply = &pb_v1.ManagementLoginReply{}

	// 捕获各个task中的异常并返回给调用者
	defer func() {
		if r := recover(); r != nil {
			err = fmt.Errorf("%+v", r)
			e := &status.Status{}
			if er := json.Unmarshal([]byte(err.Error()), e); er != nil {
				logger.Error("err",
					zap.String("system_err", err.Error()),
					zap.Stack("stacktrace"))
			}
		}
	}()

	if req.Key == "" || req.Username == "" || req.Password == "" {
		return nil, errors.ParamsError
	}

	// 机构认证
	mreq := pb_v1.OrganizationKeyAuthRequest{Key:req.Key}
	mreply, err := pb.System.OrganizationKeyAuth(ctx, &mreq)
	if err != nil {
		return nil, err
	}
	if mreply.IsDisable {
		return nil, status.Error(10003, "机构已禁用")
	}
	if mreply.EndTime <= time.Now().Unix() {
		return nil, status.Error(10003, "机构已过有效期")
	}

	// 账号认证
	dbname := utils.GetDbName(mreply.OrganizationCode)
	p := model.NewRbacUser(dbname)
	where := map[string]interface{}{
		"username":req.Username,
	}
	err = p.Find(database.DB(), where)
	if err != nil {
		if err == gorm.ErrRecordNotFound {
			return nil, status.Error(30202, "用户不存在")
		}
		return nil, errors.DataBaseError
	}

	password,_ := util.GetMd5Pass(req.Password, consts.CRYPTO_KEY)
	if password != p.Passowrd {
		return nil, errors.PasswordError
	}
	reply.OrganizationCode = mreply.OrganizationCode
	reply.EndTime = mreply.EndTime
	reply.Uid = p.Id
	reply.OrganizationName = mreply.OrganizationName
	reply.IsSuper = p.IsSuperUser

	nodeReply, err := rbac.RbacNodeListByGroupOrUser(ctx, &pb_v1.RbacNodeListByGroupOrUserRequest{OrganizationCode:mreply.OrganizationCode, GroupId:p.GroupId})
	if err != nil {
		return nil, err
	}
	for _, v := range nodeReply.List{
		reply.Permissions = append(reply.Permissions, v.Router)
	}
	return reply, nil
}
